==> ejc-zdsmaterialb-api-3.0.0-20240802.102206-4-sources.jar: com/ejianc/business/zdsmaterial/material/vo/PurchaseAnalysisVo.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import java.math.BigDecimal;

public class PurchaseAnalysisVo {


    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资类别名称
    private String propertyValue; // 规格型号
    private BigDecimal sumNum = BigDecimal.ZERO; // 初始总控量
    private BigDecimal num = BigDecimal.ZERO; // 总控量
    private BigDecimal planNum = BigDecimal.ZERO; // 采购计划量
    private BigDecimal orderNum = BigDecimal.ZERO; // 订单量
    private BigDecimal deliveryNum = BigDecimal.ZERO; // 发货量
    private BigDecimal purchaseRate = BigDecimal.ZERO; // 采购率
    private BigDecimal alreadyEntryNum = BigDecimal.ZERO; // 已入库量
    private BigDecimal alreadyOutNum = BigDecimal.ZERO; // 已出库量
    private BigDecimal inventoryNum = BigDecimal.ZERO; // 库存量
    private BigDecimal unarchivedQuantityNum = BigDecimal.ZERO; // 未到货量
    private BigDecimal outRate = BigDecimal.ZERO; // 出库率
    private BigDecimal changeNum = BigDecimal.ZERO; // 变更次数
    private BigDecimal excessNum = BigDecimal.ZERO; // 超量次数
    private BigDecimal changeAmount = BigDecimal.ZERO; // 变更量
    private BigDecimal excessAmount = BigDecimal.ZERO; // 超量
    private BigDecimal entryMny = BigDecimal.ZERO; // 入库金额
    private BigDecimal outMny = BigDecimal.ZERO; // 出库金额
    private BigDecimal inventoryMny = BigDecimal.ZERO; // 库存金额
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // 项目名称

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getPurchaseRate() {
        return purchaseRate;
    }

    public void setPurchaseRate(BigDecimal purchaseRate) {
        this.purchaseRate = purchaseRate;
    }

    public BigDecimal getAlreadyEntryNum() {
        return alreadyEntryNum;
    }

    public void setAlreadyEntryNum(BigDecimal alreadyEntryNum) {
        this.alreadyEntryNum = alreadyEntryNum;
    }

    public BigDecimal getAlreadyOutNum() {
        return alreadyOutNum;
    }

    public void setAlreadyOutNum(BigDecimal alreadyOutNum) {
        this.alreadyOutNum = alreadyOutNum;
    }

    public BigDecimal getInventoryNum() {
        return inventoryNum;
    }

    public void setInventoryNum(BigDecimal inventoryNum) {
        this.inventoryNum = inventoryNum;
    }

    public BigDecimal getUnarchivedQuantityNum() {
        return unarchivedQuantityNum;
    }

    public void setUnarchivedQuantityNum(BigDecimal unarchivedQuantityNum) {
        this.unarchivedQuantityNum = unarchivedQuantityNum;
    }

    public BigDecimal getOutRate() {
        return outRate;
    }

    public void setOutRate(BigDecimal outRate) {
        this.outRate = outRate;
    }

    public BigDecimal getChangeNum() {
        return changeNum;
    }

    public void setChangeNum(BigDecimal changeNum) {
        this.changeNum = changeNum;
    }

    public BigDecimal getExcessNum() {
        return excessNum;
    }

    public void setExcessNum(BigDecimal excessNum) {
        this.excessNum = excessNum;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public BigDecimal getExcessAmount() {
        return excessAmount;
    }

    public void setExcessAmount(BigDecimal excessAmount) {
        this.excessAmount = excessAmount;
    }

    public BigDecimal getEntryMny() {
        return entryMny;
    }

    public void setEntryMny(BigDecimal entryMny) {
        this.entryMny = entryMny;
    }

    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }

    public BigDecimal getInventoryMny() {
        return inventoryMny;
    }

    public void setInventoryMny(BigDecimal inventoryMny) {
        this.inventoryMny = inventoryMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/material/vo/PurchaseAnalysisVo.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PurchaseAnalysisVo implements Serializable {
    private static final long serialVersionUID = 7198243378291709748L;

    private Long belongOrgId;//归属组织名称
    private String belongOrgCode;//归属组织编码
    private String belongOrgName;//归属组织名称
    private Integer belongOrgType;//归属组织类型
    private Long orgId;//组织名称
    private String orgCode;//组织编码
    private String orgName;//组织名称
    private Long parentOrgId;//上级组织Id
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialTypeCode; // 物资类别名称
    private String propertyValue; // 规格型号
    private BigDecimal sumNum = BigDecimal.ZERO; // 初始总控量
    private BigDecimal num = BigDecimal.ZERO; // 总控量
    private BigDecimal planNum = BigDecimal.ZERO; // 采购计划量
    private BigDecimal orderNum = BigDecimal.ZERO; // 订单量
    private BigDecimal deliveryNum = BigDecimal.ZERO; // 发货量
    private BigDecimal purchaseRate = BigDecimal.ZERO; // 采购率
    private BigDecimal alreadyEntryNum = BigDecimal.ZERO; // 已入库量
    private BigDecimal alreadyOutNum = BigDecimal.ZERO; // 已出库量
    private BigDecimal inventoryNum = BigDecimal.ZERO; // 库存量
    private BigDecimal unarchivedQuantityNum = BigDecimal.ZERO; // 未到货量
    private BigDecimal outRate = BigDecimal.ZERO; // 出库率
    private BigDecimal changeNum = BigDecimal.ZERO; // 变更次数
    private BigDecimal excessNum = BigDecimal.ZERO; // 超量次数
    private BigDecimal changeAmount = BigDecimal.ZERO; // 变更量
    private BigDecimal excessAmount = BigDecimal.ZERO; // 超量
    private BigDecimal entryMny = BigDecimal.ZERO; // 入库金额
    private BigDecimal outMny = BigDecimal.ZERO; // 出库金额
    private BigDecimal inventoryMny = BigDecimal.ZERO; // 库存金额
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Boolean validFlag; //0-无效，1-有效

    public Boolean getValidFlag() {
        return validFlag;
    }

    public void setValidFlag(Boolean validFlag) {
        this.validFlag = validFlag;
    }

    public Long getBelongOrgId() {
        return belongOrgId;
    }

    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }

    public String getBelongOrgCode() {
        return belongOrgCode;
    }

    public void setBelongOrgCode(String belongOrgCode) {
        this.belongOrgCode = belongOrgCode;
    }

    public String getBelongOrgName() {
        return belongOrgName;
    }

    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }

    public Integer getBelongOrgType() {
        return belongOrgType;
    }

    public void setBelongOrgType(Integer belongOrgType) {
        this.belongOrgType = belongOrgType;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getPurchaseRate() {
        return purchaseRate;
    }

    public void setPurchaseRate(BigDecimal purchaseRate) {
        this.purchaseRate = purchaseRate;
    }

    public BigDecimal getAlreadyEntryNum() {
        return alreadyEntryNum;
    }

    public void setAlreadyEntryNum(BigDecimal alreadyEntryNum) {
        this.alreadyEntryNum = alreadyEntryNum;
    }

    public BigDecimal getAlreadyOutNum() {
        return alreadyOutNum;
    }

    public void setAlreadyOutNum(BigDecimal alreadyOutNum) {
        this.alreadyOutNum = alreadyOutNum;
    }

    public BigDecimal getInventoryNum() {
        return inventoryNum;
    }

    public void setInventoryNum(BigDecimal inventoryNum) {
        this.inventoryNum = inventoryNum;
    }

    public BigDecimal getUnarchivedQuantityNum() {
        return unarchivedQuantityNum;
    }

    public void setUnarchivedQuantityNum(BigDecimal unarchivedQuantityNum) {
        this.unarchivedQuantityNum = unarchivedQuantityNum;
    }

    public BigDecimal getOutRate() {
        return outRate;
    }

    public void setOutRate(BigDecimal outRate) {
        this.outRate = outRate;
    }

    public BigDecimal getChangeNum() {
        return changeNum;
    }

    public void setChangeNum(BigDecimal changeNum) {
        this.changeNum = changeNum;
    }

    public BigDecimal getExcessNum() {
        return excessNum;
    }

    public void setExcessNum(BigDecimal excessNum) {
        this.excessNum = excessNum;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public BigDecimal getExcessAmount() {
        return excessAmount;
    }

    public void setExcessAmount(BigDecimal excessAmount) {
        this.excessAmount = excessAmount;
    }

    public BigDecimal getEntryMny() {
        return entryMny;
    }

    public void setEntryMny(BigDecimal entryMny) {
        this.entryMny = entryMny;
    }

    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }

    public BigDecimal getInventoryMny() {
        return inventoryMny;
    }

    public void setInventoryMny(BigDecimal inventoryMny) {
        this.inventoryMny = inventoryMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
